----------------------------------------------------------------------------------
-- 
-- Create Date:    10:01:22 06/12/2013 
-- Design Name:    AFE
-- Module Name:    pm - Behavioral 
-- Project Name:   AFE
-- Target Devices: XC6SLX45-2CSG324
-- Tool versions:  ISE 14.5
-- Description:    PMP interface to PIC
--
-- Dependencies: 
--
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.all;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
use IEEE.NUMERIC_STD.all;

-- Uncomment the following library declaration if instantiating
-- any Xilinx primitives in this code.
library UNISIM;
use UNISIM.VComponents.all;

entity PM is
  port(
    ACLK   : in std_logic;
    RESETn : in std_logic;

    --Verbindung PIC
    pm_data : inout std_logic_vector(15 downto 0);
    pm_all  : in    std_logic;
    pm_alh  : in    std_logic;
    pm_rd   : in    std_logic;
    pm_wr   : in    std_logic;

    --Interner PMP Bus
    PMP_ADDR    : out std_logic_vector(15 downto 0);
    PMP_RD      : out std_logic;
    PMP_DATA_RD : in  std_logic_vector(15 downto 0);
    PMP_WR      : out std_logic;
    PMP_DATA_WR : out std_logic_vector(15 downto 0)
    );

end pm;

architecture Behavioral of PM is

  signal temp_DATA : std_logic_vector(15 downto 0);

--SM
  type STATE_TYPE is (RESET, ADDR, READ_PMP1, READ_PMP2, READ_PMP3, WRITE_PMP1, WRITE_PMP2);
  signal STATE : STATE_TYPE := RESET;

begin

  SM : process (ACLK)
  begin
    if ACLK = '1' and ACLK'event then
      PMP_RD      <= '0';
      PMP_WR      <= '0';
      PMP_DATA_WR <= x"0000";
      case STATE is
        when RESET =>
          if RESETn = '1' then STATE <= ADDR;
          end if;
        when ADDR =>
          if(pm_all = '1' and pm_alh = '1') then
            PMP_ADDR <= pm_data;
            PMP_RD   <= '1';
            STATE    <= READ_PMP1;
          end if;
			 if(pm_wr = '1') then
				PMP_DATA_WR <= pm_data;
				PMP_WR      <= '1';				
				STATE    <= WRITE_PMP1;
			 end if;
          if RESETn = '0' then STATE <= RESET;
          end if;
        when READ_PMP1 =>
          STATE <= READ_PMP2;
          if RESETn = '0' then 
			   STATE <= RESET;
          end if;
        when READ_PMP2 =>
          temp_data <= PMP_DATA_RD;
          STATE <= READ_PMP3;
          if RESETn = '0' then 
				STATE <= RESET;
          end if;
		  when READ_PMP3 =>
			 if(pm_all = '0' and pm_alh = '0') then
				STATE <= ADDR;			 
			 end if;
          if RESETn = '0' then 
				STATE <= RESET;
          end if;
			 
        when WRITE_PMP1 =>
          STATE <= WRITE_PMP2;
          if RESETn = '0' then 
			   STATE <= RESET;
          end if;
        when WRITE_PMP2 =>
			 if(pm_wr = '0') then
				STATE <= ADDR;			 
			 end if;
          if RESETn = '0' then 
				STATE <= RESET;
          end if;
			 
        when others =>
          STATE <= ADDR;
      end case;
		
		

		
		
    end if;
  end process SM;

  ASYNC : process (pm_rd, temp_data)
  begin
    if(pm_rd = '1') then
      pm_data <= temp_data;
    --pm_data <= "1111111111111111";
    else
      pm_data <= "ZZZZZZZZZZZZZZZZ";
    end if;
  end process ASYNC;
end Behavioral;

