-------------------------------------------------------------------------------
-- Title      : main
-- Project    :
-------------------------------------------------------------------------------
-- File       : main.vhd
-- Company    :
-- Created    : 2013-06-16
-- Last update: 2013-06-16
-- Platform   :
-- Standard   : VHDL'93/02
-------------------------------------------------------------------------------
-- Description: MAIN ALF
-------------------------------------------------------------------------------
-- Copyright (c) 2013 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

use IEEE.NUMERIC_STD.ALL;

library UNISIM;
use UNISIM.VComponents.all;

entity main is
port(
	--CLK
	clk50 : in  STD_LOGIC;
	
	--PMP
	pm_d : inout  std_logic_vector(15 downto 0);
   pm_all : in  std_logic;
   pm_alh : in  std_logic;
   pm_rd  : in  std_logic;
   pm_wr  : in  std_logic;
	
	--Gates
	gatesout : out  std_logic_vector(11 downto 0)
	);
end main;

architecture Behavioral of main is
signal clk200 : std_logic;
signal CLKFBOUT : std_logic;
signal pm_in : std_logic_vector(15 downto 0);
signal pm_out : std_logic_vector(15 downto 0);
signal pm_en : std_logic;

--PMP BUS
signal PMP_ADDR : std_logic_vector(15 downto 0);
signal PMP_WR : std_logic;
signal PMP_DATA_WR : std_logic_vector(15 downto 0); 
signal PMP_RD : std_logic;
signal PMP_DATA_RD : std_logic_vector(15 downto 0); 
signal PMP_TEST_DATA_RD : std_logic_vector(15 downto 0); 

component pm
port(
		ACLK : IN std_logic;
		RESETn : IN std_logic;
		pm_all : IN std_logic;
		pm_alh : IN std_logic;
		pm_rd : IN std_logic;
		pm_wr : IN std_logic;
		PMP_DATA_RD : IN std_logic_vector(15 downto 0);    
		pm_data : INOUT std_logic_vector(15 downto 0);      
		PMP_ADDR : OUT std_logic_vector(15 downto 0);
		PMP_RD : OUT std_logic;
		PMP_WR : OUT std_logic;
		PMP_DATA_WR : OUT std_logic_vector(15 downto 0)
	);
end component;

component pm_test
	PORT(
		ACLK : IN  std_logic;
		PADDR : IN std_logic_vector(15 downto 0);
		PRD : IN std_logic;          
		PRDATA : OUT std_logic_vector(15 downto 0);
		PWR    : in  std_logic;
	   PWDATA : in  std_logic_vector(15 downto 0)
		);
end component;

component dcm
port(
		-- Clock in ports
		CLK_IN1 : in std_logic;
		-- Clock out ports
		CLK_OUT1 : out std_logic
);
end component;


begin
PLL: dcm
  port map(
		-- Clock in ports
		CLK_IN1 => clk50,
		-- Clock out ports
		CLK_OUT1 => clk200
	);
	
PMP: pm
	port map(
		ACLK => clk200,
		RESETn => '1',
		pm_data => pm_d,
		pm_all => pm_all,
		pm_alh => pm_alh,
		pm_rd => pm_rd,
		pm_wr => pm_wr,
		PMP_ADDR => PMP_ADDR,
		PMP_RD => PMP_RD,
		PMP_DATA_RD => PMP_DATA_RD,
		PMP_WR =>PMP_WR,
		PMP_DATA_WR => PMP_DATA_WR
	);

PMP_TEST: pm_test PORT MAP(
		ACLK => clk200,
		PADDR => PMP_ADDR,
		PRD => PMP_RD,
		PRDATA => PMP_TEST_DATA_RD,
		PWR => PMP_WR,
		PWDATA => PMP_DATA_WR
	);	
	
	PMP_DATA_RD <= PMP_TEST_DATA_RD;

	gatesout(11 downto 0) <= "001100110011";

end Behavioral;
